---
title: <span class="badge object-type-scalar"></span> TerabitsPerSecond
---
# <span class="badge object-type-scalar"></span> TerabitsPerSecond

Data rate: terabits/sec

## Definition

```python
# Data rate: terabits/sec
TerabitsPerSecond: typing.Literal["Tbits"] = "Tbits"
```
